==> lamin_cli-0.17.7-py2.py3-none-any.whl: lamin_cli/_load.py <==
from __future__ import annotations
from typing import Tuple
from lamin_utils import logger
from pathlib import Path


def decompose_url(url: str) -> Tuple[str, str, str]:
    assert "transform" in url or "artifact" in url
    for entity in ["transform", "artifact"]:
        if entity in url:
            break
    uid = url.split(f"{entity}/")[1]
    instance_slug = "/".join(url.split("/")[3:5])
    return instance_slug, entity, uid


def load(entity: str, uid: str = None, key: str = None, with_env: bool = False):
    import lamindb_setup as ln_setup

    if entity.startswith("https://") and "lamin" in entity:
        url = entity
        instance, entity, uid = decompose_url(url)
    elif entity not in {"artifact", "transform"}:
        raise SystemExit("Entity has to be a laminhub URL or 'artifact' or 'transform'")
    else:
        instance = ln_setup.settings.instance.slug

    ln_setup.connect(instance)
    from lnschema_core import models as ln

    def script_to_notebook(
        transform: ln.Transform, notebook_path: Path, bump_revision: bool = False
    ) -> None:
        import jupytext
        from lamin_utils._base62 import increment_base62

        py_content = transform.source_code.replace(
            "# # transform.name", f"# # {transform.name}"
        )
        if bump_revision:
            uid = transform.uid
            new_uid = f"{uid[:-4]}{increment_base62(uid[-4:])}"
            py_content = py_content.replace(uid, new_uid)
            logger.important(f"updated uid: {uid} → {new_uid}")
        notebook = jupytext.reads(py_content, fmt="py:percent")
        jupytext.write(notebook, notebook_path)

    if entity == "transform":
        transform = (
            ln.Transform.objects.get(uid=uid)
            if uid is not None
            # if below, we take is_latest=True as the criterion, we might get draft notebooks
            # hence, we use source_code__isnull=False and order by created_at instead
            else ln.Transform.objects.filter(key=key, source_code__isnull=False)
            .order_by("-created_at")
            .first()
        )
        target_filename = transform.key
        # if Path(target_filename).exists():
        #     response = input(f"! {target_filename} exists: replace? (y/n)")
        #     if response != "y":
        #         raise SystemExit("Aborted.")
        if transform._source_code_artifact_id is not None:  # backward compat
            # need lamindb here to have .cache() available
            import lamindb as ln

            ln.settings.track_run_inputs = False
            filepath_cache = transform._source_code_artifact.cache()
            if not target_filename.endswith(transform._source_code_artifact.suffix):
                target_filename += transform._source_code_artifact.suffix
            filepath_cache.rename(target_filename)
        elif transform.source_code is not None:
            if transform.key.endswith(".ipynb"):
                script_to_notebook(transform, target_filename, bump_revision=True)
            else:
                Path(target_filename).write_text(transform.source_code)
        else:
            raise SystemExit("No source code available for this transform.")
        logger.important(f"{transform.type} is here: {target_filename}")
        if with_env:
            import lamindb as ln

            ln.settings.track_run_inputs = False
            if (
                transform.latest_run is not None
                and transform.latest_run.environment is not None
            ):
                filepath_env_cache = transform.latest_run.environment.cache()
                target_env_filename = (
                    ".".join(target_filename.split(".")[:-1]) + "__requirements.txt"
                )
                filepath_env_cache.rename(target_env_filename)
                logger.important(target_env_filename)
            else:
                logger.warning("latest transform run with environment doesn't exist")
        return target_filename
    elif entity == "artifact":
        import lamindb as ln

        ln.settings.track_run_inputs = False
        artifact = (
            ln.Artifact.get(uid)
            if uid is not None
            else ln.Artifact.filter(key=key, source_code__isnull=False)
            .order_by("-created_at")
            .first()
        )
        cache_path = artifact.cache()
        logger.important(f"artifact is here: {cache_path}")
        return cache_path

==> lamin_cli-0.17.8-py2.py3-none-any.whl: lamin_cli/_load.py <==
from __future__ import annotations
from typing import Tuple
from lamin_utils import logger
from pathlib import Path


def decompose_url(url: str) -> Tuple[str, str, str]:
    assert "transform" in url or "artifact" in url
    for entity in ["transform", "artifact"]:
        if entity in url:
            break
    uid = url.split(f"{entity}/")[1]
    instance_slug = "/".join(url.split("/")[3:5])
    return instance_slug, entity, uid


def load(entity: str, uid: str = None, key: str = None, with_env: bool = False):
    import lamindb_setup as ln_setup

    if entity.startswith("https://") and "lamin" in entity:
        url = entity
        instance, entity, uid = decompose_url(url)
    elif entity not in {"artifact", "transform"}:
        raise SystemExit("Entity has to be a laminhub URL or 'artifact' or 'transform'")
    else:
        instance = ln_setup.settings.instance.slug

    ln_setup.connect(instance)
    from lnschema_core import models as ln

    def script_to_notebook(
        transform: ln.Transform, notebook_path: Path, bump_revision: bool = False
    ) -> None:
        import jupytext
        from lamin_utils._base62 import increment_base62

        py_content = transform.source_code.replace(
            "# # transform.name", f"# # {transform.name}"
        )
        if bump_revision:
            uid = transform.uid
            new_uid = f"{uid[:-4]}{increment_base62(uid[-4:])}"
            py_content = py_content.replace(uid, new_uid)
            logger.important(f"updated uid: {uid} → {new_uid}")
        notebook = jupytext.reads(py_content, fmt="py:percent")
        jupytext.write(notebook, notebook_path)

    if entity == "transform":
        transform = (
            ln.Transform.objects.get(uid=uid)
            if uid is not None
            # if below, we take is_latest=True as the criterion, we might get draft notebooks
            # hence, we use source_code__isnull=False and order by created_at instead
            else ln.Transform.objects.filter(key=key, source_code__isnull=False)
            .order_by("-created_at")
            .first()
        )
        target_filename = transform.key
        if Path(target_filename).exists():
            response = input(f"! {target_filename} exists: replace? (y/n)")
            if response != "y":
                raise SystemExit("Aborted.")
        if transform._source_code_artifact_id is not None:  # backward compat
            # need lamindb here to have .cache() available
            import lamindb as ln

            ln.settings.track_run_inputs = False
            filepath_cache = transform._source_code_artifact.cache()
            if not target_filename.endswith(transform._source_code_artifact.suffix):
                target_filename += transform._source_code_artifact.suffix
            filepath_cache.rename(target_filename)
        elif transform.source_code is not None:
            if transform.key.endswith(".ipynb"):
                script_to_notebook(transform, target_filename, bump_revision=True)
            else:
                Path(target_filename).write_text(transform.source_code)
        else:
            raise SystemExit("No source code available for this transform.")
        logger.important(f"{transform.type} is here: {target_filename}")
        if with_env:
            import lamindb as ln

            ln.settings.track_run_inputs = False
            if (
                transform.latest_run is not None
                and transform.latest_run.environment is not None
            ):
                filepath_env_cache = transform.latest_run.environment.cache()
                target_env_filename = (
                    ".".join(target_filename.split(".")[:-1]) + "__requirements.txt"
                )
                filepath_env_cache.rename(target_env_filename)
                logger.important(target_env_filename)
            else:
                logger.warning("latest transform run with environment doesn't exist")
        return target_filename
    elif entity == "artifact":
        import lamindb as ln

        ln.settings.track_run_inputs = False
        artifact = (
            ln.Artifact.get(uid)
            if uid is not None
            else ln.Artifact.filter(key=key, source_code__isnull=False)
            .order_by("-created_at")
            .first()
        )
        cache_path = artifact.cache()
        logger.important(f"artifact is here: {cache_path}")
        return cache_path
